pm4py.algo.discovery.ocel.ocpn.variants package
===============================================

Submodules
----------

pm4py.algo.discovery.ocel.ocpn.variants.wo\_annotation module
-------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.ocel.ocpn.variants.wo_annotation
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.ocel.ocpn.variants
   :members:
   :undoc-members:
   :show-inheritance:
